pub struct StatsModelsEdge {
pub source: String,
pub destination: String,
pub filter: StringEntities,
}Expand description
A directed edge between two nodes in the stats model graph.
Edges define data flow from a source node to a destination node, optionally filtering which contrasts/outputs are passed through based on entity values.
Fields
source: Stringdestination: Stringfilter: StringEntitiesTrait Implementations
Sourceimpl Clone for StatsModelsEdge
impl Clone for StatsModelsEdge
Sourcefn clone(&self) -> StatsModelsEdge
fn clone(&self) -> StatsModelsEdge
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for StatsModelsEdge
impl RefUnwindSafe for StatsModelsEdge
impl Send for StatsModelsEdge
impl Sync for StatsModelsEdge
impl Unpin for StatsModelsEdge
impl UnsafeUnpin for StatsModelsEdge
impl UnwindSafe for StatsModelsEdge