Automatic BIDS Stats Model generation.
Analyzes a BIDS dataset’s task structure and event files to automatically create a complete BIDS-StatsModels JSON specification. This is useful as a starting point that can be manually refined.
Functions
- auto_
model - Auto-generate a BIDS Stats Model for each task in a dataset.